@@ -8,7 +8,7 @@ OLD_AKAMAI_SHARED_CDN = "cloudinary-a.akamaihd.net"
 AKAMAI_SHARED_CDN = "res.cloudinary.com"
 SHARED_CDN = AKAMAI_SHARED_CDN
 
-VERSION = "1.0.16"
+VERSION = "1.0.17"
 USER_AGENT = "cld-python-" + VERSION
 
 from cloudinary import utils
@@ -17,9 +17,13 @@ from cloudinary.compat import urlparse, parse_qs
 def import_django_settings():
     try:
         import django.conf
-        if 'CLOUDINARY' in dir(django.conf.settings):
-            return django.conf.settings.CLOUDINARY
-        else:
+        from django.core.exceptions import ImproperlyConfigured
+        try:
+            if 'CLOUDINARY' in dir(django.conf.settings):
+                return django.conf.settings.CLOUDINARY
+            else:
+                return None
+        except ImproperlyConfigured:
             return None
     except ImportError:
         return None
